@@ -1,3 +1,5 @@
+import json
+
 from .api_call import api_call
 from .device import Device
 from .entity import Entity
@@ -83,12 +85,21 @@ class Account(Entity):
         device = Device(device_data["device"], device_data)
         return device
 
-    def get_devices(self):
+    def get_devices(self, attributes=None, zones=None, include_subzones=None):
         """:obj:`list` of :obj:`Device`: Fetch a list of all devices in the account.
         """
-        result = api_call("GET", "/accounts/{}/devices".format(self._id))
-        if not result:
-            return []
+
+        params = {}
+        if attributes is not None:
+            params["attributes"] = json.dumps(attributes)
+        if zones is not None:
+            params["zones"] = json.dumps(zones)
+        if include_subzones is not None:
+            params["include_subzones"] = json.dumps(include_subzones)
+
+        result = api_call("GET", "/accounts/{}/devices".format(self._id), params=params)
+        if not isinstance(result, list):
+            raise ValueError("API returned incorrect type")
         return [Device(device_data["device"], device_data) for device_data in result]
 
     def get_zones(self):
