@@ -56,9 +56,9 @@ class Device(Entity):
 
         if response.get("status") == "success":
             return response
-
         else:
             return None
+
     @property
     def account(self):
         return self._data.get('account')
@@ -84,19 +84,15 @@ class Device(Entity):
     def get_attr(self, key):
         """Fetches a custom attribute."""
 
-        return self._data.get(key)
+        return self.get(key)
 
     def set_attr(self, key, value):
         """Sets a custom attribute."""
-        
-        return api_call("PUT", "/accounts/%s/devices/%s" % (self._data.get("account"), self._id), data = {
-            key: value,
-        })
+        self[key] = value
 
     def set_attrs(self, attrs):
         """Sets multiple custom attributes."""
-        
-        return api_call("PUT", "/accounts/%s/devices/%s" % (self._data.get("account"), self._id), data = attrs)
+        self.push(attrs)
 
     @property
     def platform(self):
@@ -300,8 +296,8 @@ class Device(Entity):
             https://docs.freedomrobotics.ai/reference#rest-api
         """
 
-        result = api_call(
+        api_call(
             "PUT",
             "/accounts/{}/devices/{}/statistics/".format(self.account, self._id),
             data=data
-        )
+        )
\ No newline at end of file
